Package: gRim
Version: 0.3.4
Title: Graphical Interaction Models
Authors@R: person(given = "Søren",
	   	    family = "Højsgaard",
                    role = c("aut", "cre"),
                    email = "sorenh@math.aau.dk")
Maintainer: Søren Højsgaard <sorenh@math.aau.dk>
Description: Provides the following types of models: Models for contingency
    tables (i.e. log-linear models) Graphical Gaussian models for multivariate
    normal data (i.e. covariance selection models) Mixed interaction models.
    Documentation about 'gRim' is provided by vignettes included in this
    package and the book by Højsgaard, Edwards and Lauritzen (2012,
    <doi:10.1007/978-1-4614-2299-0>); see 'citation("gRim")' for details.
License: GPL (>= 2)
Depends: R (>= 4.2.0), methods, gRain (>= 1.3.10), gRbase (>= 2.0.2)
Suggests: testthat (>= 2.1.0), markdown, knitr
Imports: doBy, igraph, stats4, glue, Matrix, MASS, Rcpp (>= 0.11.1)
URL: https://people.math.aau.dk/~sorenh/software/gR/
Encoding: UTF-8
VignetteBuilder: knitr
ByteCompile: yes
LinkingTo: Rcpp (>= 0.11.1), RcppArmadillo, RcppEigen, gRbase (>=
        2.0.2)
RoxygenNote: 7.3.2
NeedsCompilation: yes
Packaged: 2024-10-15 17:59:23 UTC; sorenh
Author: Søren Højsgaard [aut, cre]
Repository: CRAN
Date/Publication: 2024-10-15 20:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-25 14:01:31 UTC; unix
Archs: gRim.so.dSYM
