# Generated by roxygen2: do not edit by hand

S3method(AIC,gips_fit_class)
S3method(BIC,gips_fit_class)
S3method(CGstats,data.frame)
S3method(ciTest,array)
S3method(ciTest,data.frame)
S3method(ciTest,list)
S3method(ciTest,table)
S3method(coef,mModel)
S3method(concentration,gips_fit_class)
S3method(fit,cModel)
S3method(fit,dModel)
S3method(fit,mModel)
S3method(fitted,dModel)
S3method(formula,iModel)
S3method(getEdges,iModel)
S3method(getEdges,igraph)
S3method(getEdges,list)
S3method(getEdges,matrix)
S3method(iplot,iModel)
S3method(logLik,gips_fit_class)
S3method(plot,iModel)
S3method(print,citest)
S3method(print,dModel)
S3method(print,gips_fit_class)
S3method(print,iModel)
S3method(print,testadd)
S3method(print,testdelete)
S3method(residuals,"dModel")
S3method(sigma,gips_fit_class)
S3method(stepwise,iModel)
S3method(summary,citest)
S3method(summary,gips_fit_class)
S3method(summary,mModel)
S3method(terms,iModel)
S3method(testEdges,iModel)
S3method(testadd,iModel)
S3method(testdelete,iModel)
S3method(triangulate,dModel)
S3method(update,iModel)
export(CGstats)
export(as_K2amat)
export(as_K2graph)
export(as_amat2emat)
export(as_elist2emat)
export(as_emat2amat)
export(as_emat2cq)
export(as_emat2elist)
export(as_emat2glist)
export(as_emat2graph)
export(as_emat2igraph)
export(as_emat_complement)
export(as_glist2cq)
export(as_glist2emat)
export(as_glist2graph)
export(as_glist2igraph)
export(as_glist2out_edges)
export(as_sparse)
export(backward)
export(ciTest)
export(ciTest_df)
export(ciTest_mvn)
export(ciTest_ordinal)
export(cmod)
export(concentration)
export(dim_loglin)
export(dim_loglin_decomp)
export(dmod)
export(effloglin)
export(emat_compare)
export(emat_complement)
export(emat_sort)
export(extract_cmod_data)
export(fast_cov)
export(fit_ggm_grips)
export(forward)
export(generate_n01)
export(getEdges)
export(getInEdges)
export(getOutEdges)
export(getmi)
export(ggmfit)
export(ggmfitr)
export(glance.gips_fit_class)
export(impose_zero)
export(mmod)
export(model_line)
export(model_loop)
export(model_random)
export(model_random_tree)
export(model_rectangular_grid)
export(model_saturated)
export(model_star)
export(modify_glist)
export(order_rows)
export(parm_CGstats2mmod)
export(parm_ghk2phk)
export(parm_ghk2pms)
export(parm_moment2pms)
export(parm_phk2ghk)
export(parm_phk2pms)
export(parm_pms2ghk)
export(parm_pms2phk)
export(parse_gm_formula)
export(testEdges)
export(testInEdges)
export(testOutEdges)
export(testadd)
export(testdelete)
exportMethods(plot)
import(gRbase)
import(methods)
importFrom(MASS,ginv)
importFrom(Matrix,solve)
importFrom(Rcpp,evalCpp)
importFrom(doBy,section_fun)
importFrom(gRain,propagateLS)
importFrom(gRbase,colmat2list)
importFrom(gRbase,combn_prim)
importFrom(gRbase,is_inset)
importFrom(gRbase,names2pairs)
importFrom(gRbase,rowmat2list)
importFrom(gRbase,which.arr.index)
importFrom(glue,glue)
importFrom(igraph,"E<-")
importFrom(igraph,"V<-")
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,as_adjacency_matrix)
importFrom(igraph,as_edgelist)
importFrom(igraph,coreness)
importFrom(igraph,graph_from_adjacency_matrix)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,is_directed)
importFrom(igraph,layout.lgl)
importFrom(igraph,plot.igraph)
importFrom(igraph,sample_gnp)
importFrom(methods,as)
importFrom(stats,AIC)
importFrom(stats,BIC)
importFrom(stats,addmargins)
importFrom(stats,as.formula)
importFrom(stats,coef)
importFrom(stats,cov)
importFrom(stats,cov.wt)
importFrom(stats,cov2cor)
importFrom(stats,fitted)
importFrom(stats,formula)
importFrom(stats,ftable)
importFrom(stats,getCall)
importFrom(stats,logLik)
importFrom(stats,loglin)
importFrom(stats,na.omit)
importFrom(stats,nobs)
importFrom(stats,pchisq)
importFrom(stats,pf)
importFrom(stats,pnorm)
importFrom(stats,r2dtable)
importFrom(stats,rnorm)
importFrom(stats,sigma)
importFrom(stats,terms)
importFrom(stats,update)
importFrom(stats,update.formula)
importFrom(stats,xtabs)
importFrom(utils,combn)
importFrom(utils,str)
importMethodsFrom(stats4,plot)
useDynLib(gRim)
